==> nidx_binding-6.3.1.post17.tar.gz: nidx_binding-6.3.1.post17/nidx_paragraph/src/request_types.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

use nidx_types::query_language::BooleanExpression;

#[derive(Clone, Default)]
pub struct ParagraphSearchRequest {
    pub id: String,
    pub uuid: String,
    pub body: String,
    pub order: Option<nidx_protos::OrderBy>,
    pub faceted: Option<nidx_protos::Faceted>,
    pub page_number: i32,
    pub result_per_page: i32,
    pub with_duplicates: bool,
    pub only_faceted: bool,
    pub advanced_query: Option<String>,
    pub min_score: f32,
    pub security: Option<nidx_protos::utils::Security>,

    pub filtering_formula: Option<BooleanExpression>,
    /// Whether to do an OR/AND between prefilter results and filtering_formula
    pub filter_or: bool,
}

pub struct ParagraphSuggestRequest {
    pub body: String,
    pub filtering_formula: Option<BooleanExpression>,
    /// Whether to do an OR/AND between prefilter results and filtering_formula
    pub filter_or: bool,
}

==> nidx_binding-6.3.5.post243.tar.gz: nidx_binding-6.3.5.post243/nidx_paragraph/src/request_types.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

use nidx_types::query_language::BooleanExpression;

#[derive(Clone, Default)]
pub struct ParagraphSearchRequest {
    pub id: String,
    pub uuid: String,
    pub body: String,
    pub order: Option<nidx_protos::OrderBy>,
    pub faceted: Option<nidx_protos::Faceted>,
    pub page_number: i32,
    pub result_per_page: i32,
    pub with_duplicates: bool,
    pub only_faceted: bool,
    pub advanced_query: Option<String>,
    pub min_score: f32,
    pub security: Option<nidx_protos::utils::Security>,

    pub filtering_formula: Option<BooleanExpression<String>>,
    /// Whether to do an OR/AND between prefilter results and filtering_formula
    pub filter_or: bool,
}

pub struct ParagraphSuggestRequest {
    pub body: String,
    pub filtering_formula: Option<BooleanExpression<String>>,
    /// Whether to do an OR/AND between prefilter results and filtering_formula
    pub filter_or: bool,
}
